@@ -3,30 +3,23 @@ Tools for dealing with the authorization blueprint.
 """
 import functools
 
-from flask import g, redirect, session, url_for
+from flask import current_app, g, redirect, session, url_for
+from sqlalchemy import select
 
-from ..db import get_db
-from . import auth
+from ..database.models import User
+from .blueprint import bp
 
 
-def get_username_and_password(form):
-    """Get username and password from a form."""
-    username = form['username']
-    password = form['password']
-    return username, password
-
-
-@auth.before_app_request
+@bp.before_app_request
 def load_logged_in_user():
     # Match the user's information with the session
     user_id = session.get('user_id')
     if user_id is None:
         g.user = None
     else:
-        user_query = 'SELECT * FROM users WHERE id = ?'
-        db = get_db()
-        cursor = db.cursor()
-        g.user = cursor.execute(user_query, (user_id,)).fetchone()
+        query = select(User).where(User.id == user_id)
+        with current_app.db.session as db_session:
+            g.user = db_session.scalar(query)
 
 
 def login_required(view):
