@@ -3,10 +3,10 @@ Filters defined for the application.
 """
 from datetime import date
 
-from . import core
+from .blueprint import bp
 
 
-@core.app_context_processor
+@bp.app_context_processor
 def inject_date_today():
     """Inject a variable with today's date into the template context."""
     return dict(date_today=str(date.today()))
